@@ -623,14 +623,15 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.11',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.11',
- 'INSTALL': '/usr/lib/portage/python3.11/ebuild-helpers/xattr/install -c',
- 'INSTALL_DATA': '/usr/lib/portage/python3.11/ebuild-helpers/xattr/install -c '
-                 '-m 644',
- 'INSTALL_PROGRAM': '/usr/lib/portage/python3.11/ebuild-helpers/xattr/install '
+ 'INSTALL': '/var/tmp/portage/._portage_reinstall_.w_l7c5xx/bin/ebuild-helpers/xattr/install '
+            '-c',
+ 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.w_l7c5xx/bin/ebuild-helpers/xattr/install '
+                 '-c -m 644',
+ 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.w_l7c5xx/bin/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/usr/lib/portage/python3.11/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.w_l7c5xx/bin/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/usr/lib/portage/python3.11/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.w_l7c5xx/bin/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
